@@ -4,8 +4,12 @@ use Dancer ':syntax';
 use Dancer::Plugin;
 use Scalar::Util 'blessed';
 
+our $VERSION = '1.08';
+
 no if $] >= 5.018, warnings => 'experimental::smartmatch';
 
+use constant PLUGIN_NAME => 'jsonrpc';
+
 use Dancer::RPCPlugin::CallbackResult;
 use Dancer::RPCPlugin::DispatchFromConfig;
 use Dancer::RPCPlugin::DispatchFromPod;
@@ -19,7 +23,7 @@ my %dispatch_builder_map = (
     config => \&build_dispatcher_from_config,
 );
 
-register jsonrpc => sub {
+register PLUGIN_NAME ,=> sub {
     my ($self, $endpoint, $arguments) = plugin_args(@_);
 
     my $publisher;
@@ -36,7 +40,7 @@ register jsonrpc => sub {
 
     my $lister = Dancer::RPCPlugin::DispatchMethodList->new();
     $lister->set_partial(
-        protocol => 'jsonrpc',
+        protocol => PLUGIN_NAME,
         endpoint => $endpoint,
         methods  => [ sort keys %{ $dispatcher } ],
     );
@@ -56,15 +60,17 @@ register jsonrpc => sub {
         if ($ct ne 'application/json') {
             pass();
         }
-        debug("[handle_jsonrpc_request] Processing: ", request->body);
-
         my @requests = unjson(request->body);
+        if (!exists($requests[0]->{jsonrpc}) or $requests[0]->{jsonrpc} ne "2.0") {
+            pass();
+        }
+
+        debug("[handle_jsonrpc_request] Processing: ", request->body);
 
         content_type 'application/json';
         my @responses;
         for my $request (@requests) {
             my $method_name = $request->{method};
-            debug("[handle_jsonrpc_call($method_name)] $method_name ", $request);
 
             if (!exists $dispatcher->{$method_name}) {
                 push(
@@ -80,10 +86,19 @@ register jsonrpc => sub {
                 next;
             }
 
-            my @method_args = $request->{params};
+            my $method_args = $request->{params};
+
+            debug("[handle_jsonrpc_call($method_name)] ", $method_args);
             my Dancer::RPCPlugin::CallbackResult $continue = eval {
+                local $Dancer::RPCPlugin::ROUTE_INFO = {
+                    plugin        => PLUGIN_NAME,
+                    endpoint      => $endpoint,
+                    rpc_method    => $method_name,
+                    full_path     => request->path,
+                    http_method   => uc(request->method),
+                };
                 $callback
-                    ? $callback->(request(), $method_name, @method_args)
+                    ? $callback->(request(), $method_name, $method_args)
                     : callback_success();
             };
 
@@ -126,20 +141,20 @@ register jsonrpc => sub {
             my $package = $di->package;
 
             my $result = eval {
-                $code_wrapper->($handler, $package, $method_name, @method_args);
+                $code_wrapper->($handler, $package, $method_name, $method_args);
             };
             my $error = $@;
 
-            debug("[handled_jsonrpc_call($method_name)] ", flatten_data($result));
+            debug("[handled_jsonrpc_request($method_name)] ", flatten_data($result));
             if ($error) {
                 my $error_response = blessed($error) && $error->can('as_jsonrpc_error')
                     ? $error
                     : error_response(
                             error_code    => -32500,
                             error_message => $error,
-                            error_data    => $method_args[0],
+                            error_data    => $method_args,
                     );
-                status $error_response->return_status('jsonrpc');
+                status $error_response->return_status(PLUGIN_NAME);
                 push @responses, jsonrpc_response(
                     $request->{id},
                     %{ $error_response->as_jsonrpc_error },
@@ -172,6 +187,7 @@ register jsonrpc => sub {
             $response = to_json([grep {defined($_->{id})} @responses], $jsonise_options);
         }
 
+        debug("[jsonrpc_response] ", $response);
         return $response;
     };
 
@@ -208,7 +224,7 @@ sub build_dispatcher_from_pod {
     debug("[build_dispatcher_from_pod]");
 
     return dispatch_table_from_pod(
-        plugin   => 'jsonrpc',
+        plugin   => PLUGIN_NAME,
         packages => $pkgs,
         endpoint => $endpoint,
     );
@@ -219,7 +235,7 @@ sub build_dispatcher_from_config {
     debug("[build_dispatcher_from_config] $endpoint");
 
     return dispatch_table_from_config(
-        plugin   => 'jsonrpc',
+        plugin   => PLUGIN_NAME,
         config   => $config,
         endpoint => $endpoint,
     );
@@ -274,7 +290,7 @@ The callback will be called just before the actual rpc-code is called from the
 dispatch table. The arguments are positional: (full_request, method_name).
 
     my Dancer::RPCPlugin::CallbackResult $continue = $callback
-        ? $callback->(request(), $method_name, @method_args)
+        ? $callback->(request(), $method_name, $method_args)
         : callback_success();
 
 The callback should return a L<Dancer::RPCPlugin::CallbackResult> instance:
@@ -401,4 +417,12 @@ Creates a (partial) dispatch table from data provided in POD.
 
 (c) MMXVI - Abe Timmerman <abeltje@cpan.org>.
 
+=begin podcover_can_suck
+
+=head2 PLUGIN_NAME
+
+L<Test::Pod::Coverage> fails this test without this section :'(
+
+=end podcover_can_suck
+
 =cut
